==> ejc-assistrmat-api-3.0.0-20220331.102040-35-sources.jar: com/ejianc/business/assist/rmat/vo/ContractClauseVO.java <==
package com.ejianc.business.assist.rmat.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 周转材租赁合同-合同条款
 * 
 * @author generator
 * 
 */
public class ContractClauseVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long contractId; // 所属合同Id
    private Long changeId; // 变更主键
    private Long changeBid; // 变更子表主键
    private Long clauseNameId; // 合同条款名称Id
    private String clauseName; // 合同条款名称
    private String clauseContent; // 合同条款内容
    

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }

    @ReferSerialTransfer(referCode="contractClause")
    public Long getClauseNameId() {
        return clauseNameId;
    }

    @ReferDeserialTransfer
    public void setClauseNameId(Long clauseNameId) {
        this.clauseNameId = clauseNameId;
    }
    public String getClauseName() {
        return clauseName;
    }

    public void setClauseName(String clauseName) {
        this.clauseName = clauseName;
    }
    public String getClauseContent() {
        return clauseContent;
    }

    public void setClauseContent(String clauseContent) {
        this.clauseContent = clauseContent;
    }
    
}

==> ejc-assistrmat-api-3.0.0-20220402.032346-43-sources.jar: com/ejianc/business/assist/rmat/vo/ContractClauseVO.java <==
package com.ejianc.business.assist.rmat.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 周转材租赁合同-合同条款
 *
 * @author generator
 */
public class ContractClauseVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long contractId; // 所属合同Id
    private Long changeId; // 变更主键
    private Long changeBid; // 变更子表主键
    private Long clauseNameId; // 合同条款名称Id
    private String clauseName; // 合同条款名称
    private String clauseContent; // 合同条款内容
    private Integer necessaryStatus; // 是否必填：0-否，1-是
    

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }

    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }

    @ReferSerialTransfer(referCode = "contractClause")
    public Long getClauseNameId() {
        return clauseNameId;
    }

    @ReferDeserialTransfer
    public void setClauseNameId(Long clauseNameId) {
        this.clauseNameId = clauseNameId;
    }

    public String getClauseName() {
        return clauseName;
    }

    public void setClauseName(String clauseName) {
        this.clauseName = clauseName;
    }

    public String getClauseContent() {
        return clauseContent;
    }

    public void setClauseContent(String clauseContent) {
        this.clauseContent = clauseContent;
    }

    public Integer getNecessaryStatus() {
        return necessaryStatus;
    }

    public void setNecessaryStatus(Integer necessaryStatus) {
        this.necessaryStatus = necessaryStatus;
    }
}
